@@ -3,14 +3,15 @@
 import os
 import shutil
 import pandas as pd
-from pandasgui.utility import get_logger
 import numpy as np
-from pandasgui.constants import LOCAL_DATA_DIR
+from pandasgui.constants import LOCAL_DATASET_DIR
+import logging
 
-logger = get_logger(__name__)
+logger = logging.getLogger(__name__)
 
 __all__ = ["all_datasets",
            "simple",
+           "multiindex",
 
            "pokemon",
            "car_crashes",
@@ -21,6 +22,7 @@ __all__ = ["all_datasets",
            "titanic",
            "gapminder",
            "stockdata",
+           "trump_tweets",
            "mi_manufacturing"]
 
 dataset_names = ["pokemon",
@@ -32,6 +34,7 @@ dataset_names = ["pokemon",
                  "titanic",
                  "gapminder",
                  "stockdata",
+                 "trump_tweets",
                  "mi_manufacturing"]
 
 all_datasets = {}
@@ -40,6 +43,10 @@ all_datasets = {}
 def read_csv(path):
     if "mi_manufacturing" in path:
         return pd.read_csv(path, index_col=[0, 1, 2], header=[0, 1, 2])
+    if "stockdata" in path:
+        return pd.read_csv(path, parse_dates=['Date'])
+    if "trump_tweets" in path:
+        return pd.read_csv(path, parse_dates=['date'])
     else:
         return pd.read_csv(path)
 
@@ -50,20 +57,17 @@ def to_csv(df, path):
     else:
         return df.to_csv(path, encoding='UTF-8', index=False)
 
+
 for ix, name in enumerate(dataset_names):
-    local_data_path = os.path.join(LOCAL_DATA_DIR, f"{name}.csv")
-    os.makedirs(LOCAL_DATA_DIR, exist_ok=True)
+    local_data_path = os.path.join(LOCAL_DATASET_DIR, f"{name}.csv")
+    os.makedirs(LOCAL_DATASET_DIR, exist_ok=True)
     if os.path.exists(local_data_path):
         all_datasets[name] = read_csv(local_data_path)
     else:
         url = f"https://raw.githubusercontent.com/adamerose/datasets/master/{name}.csv"
         all_datasets[name] = read_csv(url)
         to_csv(all_datasets[name], local_data_path)
-        logger.info(f"Saved {url} to {LOCAL_DATA_DIR}")
-
-# Add the datasets to globals so they can be imported like `from pandasgui.datasets import iris`
-for name in all_datasets.keys():
-    globals()[name] = all_datasets[name]
+        logger.info(f"Saved {url} to {LOCAL_DATASET_DIR}")
 
 simple = pd.DataFrame({'name': ['John', 'John', 'Mary', 'Mary', 'Pete', 'Pete', 'Mike', 'Mike'],
                        'gender': ['m', 'm', 'f', 'f', 'm', 'm', 'm', 'm'],
@@ -71,6 +75,7 @@ simple = pd.DataFrame({'name': ['John', 'John', 'Mary', 'Mary', 'Pete', 'Pete',
                        'time': [473, 439, 424, 419, 433, 374, 434, 345],
                        'points': [13, 16, 13, 18, 9, 20, 5, 18]}
                       )
+all_datasets['simple'] = simple
 
 multiindex = pd.DataFrame(np.random.randn(8, 4),
                           index=pd.MultiIndex.from_product([('bar', 'baz', 'foo', 'qux'),
@@ -79,3 +84,17 @@ multiindex = pd.DataFrame(np.random.randn(8, 4),
                           columns=pd.MultiIndex.from_tuples([('A', 'cat'), ('B', 'dog'),
                                                              ('B', 'cat'), ('A', 'dog')],
                                                             names=['exp', 'animal']))
+all_datasets['multiindex'] = multiindex
+
+unhashable = pd.DataFrame({'lists': [[1, 2, 3], [4, 5, 6], [7, 8, 9]],
+                           'dicts': [{'a': 1}, {'b': 2}, {'c': 3}],
+                           'dicts_of_lists': [{'a': [1, 2, 3]}, {'b': [4, 5, 6]}, {'c': [7, 8, 9]}],
+                           'sets': [{1, 2, 3}, {4, 5, 6}, {7, 8, 9}],
+                           'tuples': [(1, 2, 3), (4, 5, 6), (7, 8, 9)]
+                           }
+                          )
+all_datasets['unhashable'] = unhashable
+
+# Add the datasets to globals so they can be imported like `from pandasgui.datasets import iris`
+for name in all_datasets.keys():
+    globals()[name] = all_datasets[name]
