@@ -4,22 +4,22 @@ import pandas as pd
 from PyQt5 import QtCore, QtGui, QtWidgets
 from PyQt5.QtCore import Qt
 
-from pandasgui.utility import get_logger
+from pandasgui.utility import nunique
 from pandasgui.widgets.dataframe_viewer import DataFrameViewer
 from pandasgui.widgets.grapher import Grapher
 from pandasgui.widgets.reshaper import Reshaper
 from pandasgui.widgets.filter_viewer import FilterViewer
 from pandasgui.widgets.dock_widget import DockWidget
-from pandasgui.store import PandasGuiDataFrame
-
-logger = get_logger(__name__)
+from pandasgui.store import PandasGuiDataFrameStore
 
+import logging
+logger = logging.getLogger(__name__)
 
 class DataFrameExplorer(QtWidgets.QMainWindow):
-    def __init__(self, pgdf: PandasGuiDataFrame):
+    def __init__(self, pgdf: PandasGuiDataFrameStore):
         super().__init__()
 
-        pgdf = PandasGuiDataFrame.cast(pgdf)
+        pgdf = PandasGuiDataFrameStore.cast(pgdf)
         pgdf.dataframe_explorer = self
         self.pgdf = pgdf
 
@@ -29,27 +29,35 @@ class DataFrameExplorer(QtWidgets.QMainWindow):
         self.setTabPosition(Qt.AllDockWidgetAreas, QtWidgets.QTabWidget.North)
 
         # DataFrame tab
-        self.dataframe_tab = DataFrameViewer(pgdf)
-        self.dataframe_dock = self.add_view(self.dataframe_tab, "DataFrame")
+        self.dataframe_viewer = DataFrameViewer(pgdf)
+        self.dataframe_dock = self.add_view(self.dataframe_viewer, "DataFrame")
 
         # Filters tab
-        self.filters_tab = FilterViewer(pgdf)
-        self.filters_dock = self.add_view(self.filters_tab, "Filters")
+        self.filter_viewer = FilterViewer(pgdf)
+        self.filters_dock = self.add_view(self.filter_viewer, "Filters")
 
         # Statistics tab
-        self.statistics_tab = self.make_statistics_tab(pgdf)
-        self.statistics_dock = self.add_view(self.statistics_tab, "Statistics")
+        self.statistics_viewer = self.make_statistics_tab(pgdf)
+        self.statistics_dock = self.add_view(self.statistics_viewer, "Statistics")
 
         # Grapher tab
-        self.grapher_tab = Grapher(pgdf)
-        self.grapher_dock = self.add_view(self.grapher_tab, "Grapher")
+        self.grapher = Grapher(pgdf)
+        self.grapher_dock = self.add_view(self.grapher, "Grapher")
 
         # Reshaper tab
-        self.reshaper_tab = Reshaper(pgdf)
-        self.reshaper_dock = self.add_view(self.reshaper_tab, "Reshaper")
+        self.reshaper = Reshaper(pgdf)
+        self.reshaper_dock = self.add_view(self.reshaper, "Reshaper")
+
+        def set_active_tab(name):
+            self.active_tab = name
+        self.dataframe_dock.activated.connect(lambda: set_active_tab("DataFrame"))
+        self.filters_dock.activated.connect(lambda: set_active_tab("Filters"))
+        self.statistics_dock.activated.connect(lambda: set_active_tab("Statistics"))
+        self.grapher_dock.activated.connect(lambda: set_active_tab("Grapher"))
+        self.reshaper_dock.activated.connect(lambda: set_active_tab("Reshaper"))
 
         # Layout
-        self.dataframe_tab.setSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
+        self.dataframe_viewer.setSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
         # self.addDockWidget(Qt.RightDockWidgetArea, self.filters_dock)
 
     def add_view(self, widget: QtWidgets.QWidget, title: str):
@@ -78,21 +86,23 @@ class DataFrameExplorer(QtWidgets.QMainWindow):
         # This is so dataclasses.asdict doesn't complain about this being unpicklable
         return "DataFrameExplorer"
 
-    def make_statistics_tab(self, pgdf: PandasGuiDataFrame):
+    def make_statistics_tab(self, pgdf: PandasGuiDataFrameStore):
+
         stats_df = pd.DataFrame(
             {
-                "Type": pgdf.dataframe.dtypes.replace("object", "string").astype(str),
-                "Count": pgdf.dataframe.count(),
-                "N Unique": pgdf.dataframe.nunique(),
-                "Mean": pgdf.dataframe.mean(numeric_only=True),
-                "StdDev": pgdf.dataframe.std(numeric_only=True),
-                "Min": pgdf.dataframe.min(numeric_only=True),
-                "Max": pgdf.dataframe.max(numeric_only=True),
-            }
+                "Type": pgdf.df.dtypes.replace("object", "string").astype(str),
+                "Count": pgdf.df.count(),
+                "N Unique": nunique(pgdf.df),
+                "Mean": pgdf.df.mean(numeric_only=True),
+                "StdDev": pgdf.df.std(numeric_only=True),
+                "Min": pgdf.df.min(numeric_only=True),
+                "Max": pgdf.df.max(numeric_only=True),
+            },
+            index=pgdf.df.columns
         )
 
-        stats_pgdf = PandasGuiDataFrame(stats_df.reset_index())
-        w = DataFrameViewer(stats_pgdf)
+        self.stats_pgdf = PandasGuiDataFrameStore(stats_df.reset_index())
+        w = DataFrameViewer(self.stats_pgdf)
         w.setAutoFillBackground(True)
         return w
 
